@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Mouse;
 
-our $VERSION = '0.0.26';
+our $VERSION = '0.0.28';
 
 
 #_* Libraries
@@ -21,7 +21,7 @@ Proc::Launcher - yet another forking process controller
 
 =head1 VERSION
 
-version 0.0.26
+version 0.0.28
 
 =head1 SYNOPSIS
 
@@ -387,16 +387,17 @@ sub start {
     if ( my $pid = fork ) {    # PARENT
 
         print "LAUNCHED CHILD PROCESS: pid=$pid log=$log\n";
+
+        unless ( $self->write_my_pid( $pid ) ) {
+            print "CHILD PROCESS ALREADY RUNNING\n";
+            exit 1;
+        }
+
         return $pid;
 
     }
     else {                     # CHILD
 
-        unless ( $self->write_my_pid() ) {
-            print "CHILD PROCESS ALREADY RUNNING\n";
-            exit 1;
-        }
-
         #chdir '/'                          or die "Can't chdir to /: $!";
 
         # wu - ugly bug fix - when closing STDIN, it becomes free and
@@ -702,17 +703,19 @@ starting a daemon at the same time.
 =cut
 
 sub write_my_pid {
-    my ( $self ) = @_;
+    my ( $self, $pid ) = @_;
+
+    unless ( $pid ) { $pid = $$ }
 
     # try to read the pidfile and see if the pid therein is active
     return if $self->is_running();
 
     # write the pid to a temporary file
-    my $path = join ".", $self->pid_file, $$;
+    my $path = join ".", $self->pid_file, $pid;
     $self->_debug( "WRITING PID TO: $path" );
     open(my $pid_fh, ">", $path)
         or die "Couldn't open $path for writing: $!\n";
-    print $pid_fh $$;
+    print $pid_fh $pid;
     close $pid_fh or die "Error closing file: $!\n";
 
     # if some other process has created a pidfile since we last
